# Pipeline Maker

Adopted in "Assisted Knowledge Graph Building Using Pre-Trained Language Models"

This tool allows you to create custom GPT-3 pipelines easily.
It is possible to integrate python script to manipulate results.

(Documentation under construction)
